import {Component, OnDestroy, OnInit} from '@angular/core'
import {AppState} from '../../app-state'
import {Employee} from '../../model/employee'
import {Subject} from 'rxjs'
import {takeUntil} from 'rxjs/operators'
import {UrlUtils} from '../../utils/url.utils'
import {ActivatedRoute, Router} from '@angular/router'

@Component({
  selector: 'cre-employee-menu',
  templateUrl: './employee-menu.component.html',
  styleUrls: ['./employee-menu.component.sass']
})
export class EmployeeMenuComponent implements OnInit, OnDestroy {
  authenticated = false
  employee: Employee = null
  employeeInGroup = false
  menuEnabled = false

  private destroy$ = new Subject<boolean>()
  private urlUtils: UrlUtils

  constructor(
    private appState: AppState,
    private router: Router,
    private activatedRoute: ActivatedRoute
  ) {
    this.urlUtils = new UrlUtils(activatedRoute, router)
  }

  ngOnInit(): void {
    this.authenticationState(this.appState.isAuthenticated, this.appState.authenticatedEmployee)
    this.appState.authenticatedUser$
      .pipe(takeUntil(this.destroy$))
      .subscribe({
        next: authentication => this.authenticationState(authentication.authenticated, authentication.authenticatedUser)
      })
  }

  ngOnDestroy(): void {
    this.destroy$.next(true)
    this.destroy$.complete()
  }

  openLogin() {
    this.urlUtils.navigateTo('/account/login')
    this.menuEnabled = false
  }

  openLogout() {
    this.urlUtils.navigateTo('/account/logout')
    this.menuEnabled = false
  }

  private authenticationState(authenticated: boolean, employee: Employee) {
    this.authenticated = authenticated
    this.employee = employee
    if (this.employee != null) {
      this.employeeInGroup = this.employee.group != null
    }
  }
}
